@@ -18,7 +18,11 @@ import os
 with open(os.path.join(os.path.dirname(__file__), "VERSION")) as file:
     __version__ = file.read().strip()
 
-from .utils import ICOCO_VERSION, ICOCO_MAJOR_VERSION, ICOCO_MINOR_VERSION, ValueType, medcoupling
+from .utils import ICOCO_VERSION, ICOCO_MAJOR_VERSION, ICOCO_MINOR_VERSION, ValueType
+try:
+    from .utils import medcoupling
+except ImportError:
+    pass
 
 from .exception import WrongContext, WrongArgument, NotImplementedMethod
 
