@@ -14,7 +14,11 @@ This module contains the API for ICoCo specifications
 from abc import ABC, abstractmethod
 from typing import List, Tuple
 
-from icoco.utils import ICOCO_MAJOR_VERSION, ValueType, medcoupling, MPIComm # type: ignore
+from icoco.utils import ICOCO_MAJOR_VERSION, ValueType, MPIComm # type: ignore
+try:
+    from icoco.utils import medcoupling
+except ImportError:
+    pass
 from icoco.exception import NotImplementedMethod
 
 class Problem(ABC):
@@ -618,7 +622,7 @@ class Problem(ABC):
         """
         raise NotImplementedMethod(prob=self.problem_name, method="getFieldUnit")
 
-    def getInputMEDDoubleFieldTemplate(self, name: str) -> medcoupling.MEDCouplingFieldDouble:
+    def getInputMEDDoubleFieldTemplate(self, name: str) -> 'medcoupling.MEDCouplingFieldDouble':
         """(Optional) Retrieve an empty shell for an input field. This shell can be filled by the
         caller and then be given to the code via setInputField(). The field has the MEDDoubleField
         format.
@@ -654,7 +658,7 @@ class Problem(ABC):
         """
         raise NotImplementedMethod(prob=self.problem_name, method="getInputMEDDoubleFieldTemplate")
 
-    def setInputMEDDoubleField(self, name: str, afield: medcoupling.MEDCouplingFieldDouble) -> None:
+    def setInputMEDDoubleField(self, name: str, afield: 'medcoupling.MEDCouplingFieldDouble') -> None:
         """(Optional) Provide the code with input data in the form of a MEDDoubleField.
 
         The method getInputFieldTemplate(), if implemented, may be used first to prepare an empty
@@ -683,7 +687,7 @@ class Problem(ABC):
         """
         raise NotImplementedMethod(prob=self.problem_name, method="setInputMEDDoubleField")
 
-    def getOutputMEDDoubleField(self, name: str) -> medcoupling.MEDCouplingFieldDouble:
+    def getOutputMEDDoubleField(self, name: str) -> 'medcoupling.MEDCouplingFieldDouble':
         """(Optional) Retrieve output data from the code in the form of a MEDDoubleField.
 
         Gets the output field corresponding to name from the code into the afield argument.
@@ -714,7 +718,7 @@ class Problem(ABC):
 
     def updateOutputMEDDoubleField(self,
                                    name: str,
-                                   afield: medcoupling.MEDCouplingFieldDouble) -> None:
+                                   afield: 'medcoupling.MEDCouplingFieldDouble') -> None:
         """(Optional) Update a previously retrieved output field.
 
         (New in version 2) This methods allows the code to implement a more efficient update of a
@@ -745,7 +749,7 @@ class Problem(ABC):
         """
         raise NotImplementedMethod(prob=self.problem_name, method="updateOutputMEDDoubleField")
 
-    def getInputMEDIntFieldTemplate(self, name: str) -> medcoupling.MEDCouplingFieldInt:
+    def getInputMEDIntFieldTemplate(self, name: str) -> 'medcoupling.MEDCouplingFieldInt':
         """Similar to getInputMEDDoubleFieldTemplate() but for MEDIntField.
 
         See Also
@@ -771,7 +775,7 @@ class Problem(ABC):
         """
         raise NotImplementedMethod(prob=self.problem_name, method="getInputMEDIntFieldTemplate")
 
-    def setInputMEDIntField(self, name: str, afield: medcoupling.MEDCouplingFieldInt) -> None:
+    def setInputMEDIntField(self, name: str, afield: 'medcoupling.MEDCouplingFieldInt') -> None:
         """Similar to setInputMEDDoubleField() but for MEDIntField.
 
         See Also
@@ -796,7 +800,7 @@ class Problem(ABC):
         """
         raise NotImplementedMethod(prob=self.problem_name, method="setInputMEDIntField")
 
-    def getOutputMEDIntField(self, name: str) -> medcoupling.MEDCouplingFieldInt:
+    def getOutputMEDIntField(self, name: str) -> 'medcoupling.MEDCouplingFieldInt':
         """Similar to getOutputMEDDoubleField() but for MEDIntField.
 
         See Also
@@ -823,7 +827,7 @@ class Problem(ABC):
         raise NotImplementedMethod(prob=self.problem_name, method="getOutputMEDIntField")
     def updateOutputMEDIntField(self,
                                    name: str,
-                                   afield: medcoupling.MEDCouplingFieldInt) -> None:
+                                   afield: 'medcoupling.MEDCouplingFieldInt') -> None:
         """Similar to getInputMEDDoubleFieldTemplate() but for MEDStringField.
 
         See Also
@@ -848,7 +852,7 @@ class Problem(ABC):
         raise NotImplementedMethod(prob=self.problem_name, method="updateOutputMEDIntField")
 
 
-    def getInputMEDStringFieldTemplate(self, name: str) -> medcoupling.MEDCouplingField:
+    def getInputMEDStringFieldTemplate(self, name: str) -> 'medcoupling.MEDCouplingField':
         """Similar to getInputMEDDoubleFieldTemplate() but for MEDStringField.
 
         Warning
@@ -878,7 +882,7 @@ class Problem(ABC):
         """
         raise NotImplementedMethod(prob=self.problem_name, method="getInputMEDStringFieldTemplate")
 
-    def setInputMEDStringField(self, name: str, afield: medcoupling.MEDCouplingField) -> None:
+    def setInputMEDStringField(self, name: str, afield: 'medcoupling.MEDCouplingField') -> None:
         """Similar to setInputMEDDoubleField() but for MEDStringField.
 
         Warning
@@ -907,7 +911,7 @@ class Problem(ABC):
         """
         raise NotImplementedMethod(prob=self.problem_name, method="setInputMEDStringField")
 
-    def getOutputMEDStringField(self, name: str) -> medcoupling.MEDCouplingField:
+    def getOutputMEDStringField(self, name: str) -> 'medcoupling.MEDCouplingField':
         """Similar to getOutputMEDDoubleField() but for MEDStringField.
 
         Warning
@@ -938,7 +942,7 @@ class Problem(ABC):
         raise NotImplementedMethod(prob=self.problem_name, method="getOutputMEDStringField")
     def updateOutputMEDStringField(self,
                                    name: str,
-                                   afield: medcoupling.MEDCouplingField) -> None:
+                                   afield: 'medcoupling.MEDCouplingField') -> None:
         """Similar to getInputMEDDoubleFieldTemplate() but for MEDStringField.
 
         Warning
