@@ -12,7 +12,11 @@ It supports proper management of the TIME_STEP_CONTEXT and scope of usage of the
 import os
 from typing import List, Tuple
 
-from icoco.utils import ICOCO_MAJOR_VERSION, ValueType, medcoupling, MPIComm # type: ignore
+from icoco.utils import ICOCO_MAJOR_VERSION, ValueType, MPIComm # type: ignore
+try:
+    from icoco.utils import medcoupling
+except ImportError:
+    pass
 from icoco.exception import WrongArgument, WrongContext
 from icoco.problem import Problem
 
@@ -901,7 +905,7 @@ class ProblemWrapper:
     #     subsection MED*Field fields I/O
     # ******************************************************
 
-    def getInputMEDDoubleFieldTemplate(self, name: str) -> medcoupling.MEDCouplingFieldDouble:
+    def getInputMEDDoubleFieldTemplate(self, name: str) -> 'medcoupling.MEDCouplingFieldDouble':
         """(Optional) Retrieve an empty shell for an input field. This shell can be filled by the
         caller and then be given to the code via setInputField(). The field has the MEDDoubleField
         format.
@@ -943,7 +947,7 @@ class ProblemWrapper:
 
         return self._impl.getInputMEDDoubleFieldTemplate(name)
 
-    def setInputMEDDoubleField(self, name: str, afield: medcoupling.MEDCouplingFieldDouble) -> None:
+    def setInputMEDDoubleField(self, name: str, afield: 'medcoupling.MEDCouplingFieldDouble') -> None:
         """(Optional) Provide the code with input data in the form of a MEDDoubleField.
 
         The method getInputFieldTemplate(), if implemented, may be used first to prepare an empty
@@ -979,7 +983,7 @@ class ProblemWrapper:
         return self._impl.setInputMEDDoubleField(name=name, afield=afield)
 
 
-    def getOutputMEDDoubleField(self, name: str) -> medcoupling.MEDCouplingFieldDouble:
+    def getOutputMEDDoubleField(self, name: str) -> 'medcoupling.MEDCouplingFieldDouble':
         """(Optional) Retrieve output data from the code in the form of a MEDDoubleField.
 
         Gets the output field corresponding to name from the code into the afield argument.
@@ -1014,7 +1018,7 @@ class ProblemWrapper:
 
     def updateOutputMEDDoubleField(self,
                                    name: str,
-                                   afield: medcoupling.MEDCouplingFieldDouble) -> None:
+                                   afield: 'medcoupling.MEDCouplingFieldDouble') -> None:
         """(Optional) Update a previously retrieved output field.
 
         (New in version 2) This methods allows the code to implement a more efficient update of a
@@ -1049,7 +1053,7 @@ class ProblemWrapper:
                                precondition="called before initialize() or after terminate()")
         return self._impl.updateOutputMEDDoubleField(name=name, afield=afield)
 
-    def getInputMEDIntFieldTemplate(self, name: str) -> medcoupling.MEDCouplingFieldInt:
+    def getInputMEDIntFieldTemplate(self, name: str) -> 'medcoupling.MEDCouplingFieldInt':
         """Similar to getInputMEDDoubleFieldTemplate() but for MEDIntField.
 
         See Also
@@ -1080,7 +1084,7 @@ class ProblemWrapper:
 
         return self._impl.getInputMEDIntFieldTemplate(name)
 
-    def setInputMEDIntField(self, name: str, afield: medcoupling.MEDCouplingFieldInt) -> None:
+    def setInputMEDIntField(self, name: str, afield: 'medcoupling.MEDCouplingFieldInt') -> None:
         """Similar to setInputMEDDoubleField() but for MEDIntField.
 
         See Also
@@ -1110,7 +1114,7 @@ class ProblemWrapper:
 
         return self._impl.setInputMEDIntField(name=name, afield=afield)
 
-    def getOutputMEDIntField(self, name: str) -> medcoupling.MEDCouplingFieldInt:
+    def getOutputMEDIntField(self, name: str) -> 'medcoupling.MEDCouplingFieldInt':
         """Similar to getOutputMEDDoubleField() but for MEDIntField.
 
         See Also
@@ -1143,7 +1147,7 @@ class ProblemWrapper:
 
     def updateOutputMEDIntField(self,
                                    name: str,
-                                   afield: medcoupling.MEDCouplingFieldInt) -> None:
+                                   afield: 'medcoupling.MEDCouplingFieldInt') -> None:
         """Similar to getInputMEDDoubleFieldTemplate() but for MEDStringField.
 
         See Also
@@ -1172,7 +1176,7 @@ class ProblemWrapper:
 
         return self._impl.updateOutputMEDIntField(name, afield)
 
-    def getInputMEDStringFieldTemplate(self, name: str) -> medcoupling.MEDCouplingField:
+    def getInputMEDStringFieldTemplate(self, name: str) -> 'medcoupling.MEDCouplingField':
         """Similar to getInputMEDDoubleFieldTemplate() but for MEDStringField.
 
         Warning
@@ -1207,7 +1211,7 @@ class ProblemWrapper:
 
         return self._impl.getInputMEDStringFieldTemplate(name)
 
-    def setInputMEDStringField(self, name: str, afield: medcoupling.MEDCouplingField) -> None:
+    def setInputMEDStringField(self, name: str, afield: 'medcoupling.MEDCouplingField') -> None:
         """Similar to setInputMEDDoubleField() but for MEDStringField.
 
         Warning
@@ -1241,7 +1245,7 @@ class ProblemWrapper:
 
         return self._impl.setInputMEDStringField(name=name, afield=afield)
 
-    def getOutputMEDStringField(self, name: str) -> medcoupling.MEDCouplingField:
+    def getOutputMEDStringField(self, name: str) -> 'medcoupling.MEDCouplingField':
         """Similar to getOutputMEDDoubleField() but for MEDStringField.
 
         Warning
@@ -1278,7 +1282,7 @@ class ProblemWrapper:
 
     def updateOutputMEDStringField(self,
                                    name: str,
-                                   afield: medcoupling.MEDCouplingField) -> None:
+                                   afield: 'medcoupling.MEDCouplingField') -> None:
         """Similar to getInputMEDDoubleFieldTemplate() but for MEDStringField.
 
         Warning
