@@ -10,7 +10,12 @@ https://github.com/cea-trust-platform/icoco-coupling
 
 from enum import Enum
 
-import medcoupling # pylint: disable=unused-import
+try:
+    import medcoupling # pylint: disable=unused-import
+except ImportError:
+    import warnings
+    warnings.warn(message="medcoupling module not found",
+                  category=ImportWarning)
 
 ICOCO_VERSION="2.0"
 ICOCO_MAJOR_VERSION=2
